summaryrefslogtreecommitdiffstats
path: root/noatun/modules/kaiman/style.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'noatun/modules/kaiman/style.cpp')
-rw-r--r--noatun/modules/kaiman/style.cpp48
1 files changed, 24 insertions, 24 deletions
diff --git a/noatun/modules/kaiman/style.cpp b/noatun/modules/kaiman/style.cpp
index 4f9b5315..bbf55cb3 100644
--- a/noatun/modules/kaiman/style.cpp
+++ b/noatun/modules/kaiman/style.cpp
@@ -42,8 +42,8 @@ const bool KaimanStyleSlider::optionVertical = 1;
const bool KaimanStyleSlider::optionReversed = 2;
const bool KaimanStyleText::optionExtended = 1;
-KaimanStyleElement::KaimanStyleElement(TQWidget *tqparent, const char *name)
- : TQWidget(tqparent, name)
+KaimanStyleElement::KaimanStyleElement(TQWidget *parent, const char *name)
+ : TQWidget(parent, name)
{
// Initialize everything to default values
filename = "";
@@ -122,10 +122,10 @@ void KaimanStyleElement::loadPixmaps(TQString &val_s_filename)
bitBlt(part,0,0,&pixmap,sourcex,sourcey,w,h);
pixmaps.insert(i,part);
- if(pixmap.tqmask())
+ if(pixmap.mask())
{
TQBitmap maskpart(w,h);
- bitBlt(&maskpart,0,0,pixmap.tqmask(),sourcex,sourcey,w,h);
+ bitBlt(&maskpart,0,0,pixmap.mask(),sourcex,sourcey,w,h);
part->setMask(maskpart);
}
@@ -192,8 +192,8 @@ void KaimanStyleElement::dropEvent( TQDropEvent *event )
/***************************************************************************/
-KaimanStyleButton::KaimanStyleButton(TQWidget *tqparent, const char *name)
- : KaimanStyleMasked(tqparent, name)
+KaimanStyleButton::KaimanStyleButton(TQWidget *parent, const char *name)
+ : KaimanStyleMasked(parent, name)
{
i_b_lit = i_b_prelit = i_b_down = false;
i_i_currentState = NormalUp;
@@ -327,8 +327,8 @@ void KaimanStyleButton::updateButtonState() {
/***********************************************************************/
-KaimanStyleSlider::KaimanStyleSlider(int min, int max, TQWidget *tqparent, const char *name)
- : KaimanStyleMasked( tqparent, name )
+KaimanStyleSlider::KaimanStyleSlider(int min, int max, TQWidget *parent, const char *name)
+ : KaimanStyleMasked( parent, name )
{
_min = min;
_max = max;
@@ -486,8 +486,8 @@ void KaimanStyleSlider::leaveEvent ( TQEvent * e )
/***********************************************************************/
-KaimanStyleBackground::KaimanStyleBackground(TQWidget *tqparent, const char *name)
- : KaimanStyleMasked( tqparent, name )
+KaimanStyleBackground::KaimanStyleBackground(TQWidget *parent, const char *name)
+ : KaimanStyleMasked( parent, name )
{
i_b_move = false;
}
@@ -533,8 +533,8 @@ void KaimanStyleBackground::mousePressEvent(TQMouseEvent *qme)
/***********************************************************************/
-KaimanStyleValue::KaimanStyleValue(int min, int max, TQWidget *tqparent, const char *name)
- : KaimanStyleMasked( tqparent, name )
+KaimanStyleValue::KaimanStyleValue(int min, int max, TQWidget *parent, const char *name)
+ : KaimanStyleMasked( parent, name )
{
_min = min;
_max = max;
@@ -571,8 +571,8 @@ void KaimanStyleValue::setValue( int value, int min, int max )
/***********************************************************************/
-KaimanStyleNumber::KaimanStyleNumber(TQWidget *tqparent, const char *name)
- : KaimanStyleElement( tqparent, name )
+KaimanStyleNumber::KaimanStyleNumber(TQWidget *parent, const char *name)
+ : KaimanStyleElement( parent, name )
{
//kdDebug(66666) << k_funcinfo << "name = '" << name << "'" << endl;
_value = 0;
@@ -640,8 +640,8 @@ void KaimanStyleNumber::paintEvent(TQPaintEvent */*qpe*/)
/***********************************************************************/
-KaimanStyleText::KaimanStyleText(TQWidget *tqparent, const char *name)
- : KaimanStyleElement( tqparent, name )
+KaimanStyleText::KaimanStyleText(TQWidget *parent, const char *name)
+ : KaimanStyleElement( parent, name )
{
_pos = 0;
_timer = new TQTimer( this );
@@ -735,8 +735,8 @@ void KaimanStyleText::paintEvent(TQPaintEvent */*qpe*/)
/***********************************************************************/
-KaimanStyleAnimation::KaimanStyleAnimation(int delay, TQWidget *tqparent, const char *name)
- : KaimanStyleMasked( tqparent, name )
+KaimanStyleAnimation::KaimanStyleAnimation(int delay, TQWidget *parent, const char *name)
+ : KaimanStyleMasked( parent, name )
{
_delay = delay;
_frame = 0;
@@ -774,8 +774,8 @@ void KaimanStyleAnimation::timeout()
/***********************************************************************/
-KaimanStyleState::KaimanStyleState(TQWidget *tqparent, const char *name)
- : KaimanStyleMasked( tqparent, name )
+KaimanStyleState::KaimanStyleState(TQWidget *parent, const char *name)
+ : KaimanStyleMasked( parent, name )
{
_value = 0;
}
@@ -799,10 +799,10 @@ void KaimanStyleState::mousePressEvent(TQMouseEvent *qme)
/***********************************************************************/
-KaimanStyle::KaimanStyle( TQWidget *tqparent, const char *name )
- : TQWidget( tqparent, name )
+KaimanStyle::KaimanStyle( TQWidget *parent, const char *name )
+ : TQWidget( parent, name )
{
- i_qw_parent = tqparent;
+ i_qw_parent = parent;
i_eventSemaphore = false;
}
@@ -1456,7 +1456,7 @@ bool KaimanStyle::loadPixmaps()
if ( (l_pixmap_Background != 0) && (l_pixmap_Mask != 0) ) {
// OK, background and tqmask are defined. So now I can calculate the tqshape
int l_i_width_Mask = l_pixmap_Mask->width();
int l_i_height_Mask = l_pixmap_Mask->height();
@@ -1456,7 +1456,7 @@ bool KaimanStyle::loadPixmaps()
if ( (l_pixmap_Background != 0) && (l_pixmap_Mask != 0) ) {
- // OK, background and tqmask are defined. So now I can calculate the tqshape
+ // OK, background and mask are defined. So now I can calculate the tqshape
int l_i_width_Mask = l_pixmap_Mask->width();
int l_i_height_Mask = l_pixmap_Mask->height();